##
# @brief Includes `libvterm` (builds it if not found on the system).
#
# Provides ${LIBVTERM_LIBRARY} and implicitly adds path for correct
# `#include<>`.
#
# @warning dependency must be added like this:
#          if(TARGET libvtermProject)
#              add_dependencies(<targetDependingOn> libvtermProject)
#          endif()
#
# @author Christian Burger <christian@krikkel.de>


find_library(LIBVTERM_LIBRARY NAMES libvterm.so.0.0.2 vterm)

include(ExternalProject)

if(LIBVTERM_LIBRARY STREQUAL "LIBVTERM_LIBRARY-NOTFOUND")
    message(STATUS "libvterm not found — building it")
    ExternalProject_Add(
        libvtermProject
        DOWNLOAD_COMMAND URL "https://launchpad.net/ubuntu/+archive/primary/+sourcefiles/libvterm/0.1.2-2/libvterm_0.1.2.orig.tar.gz"
        CONFIGURE_COMMAND ""
        BUILD_IN_SOURCE true
        INSTALL_COMMAND ""
    )
    ExternalProject_Get_property(libvtermProject SOURCE_DIR)
    set(LIBVTERM_LIBRARY "${SOURCE_DIR}/.libs/libvterm.a")
    include_directories(SYSTEM "${SOURCE_DIR}/include")
endif()
